# sphinx-thebe

[![Documentation](https://readthedocs.org/projects/sphinx-thebe/badge/?version=latest)](https://sphinx-thebe.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/sphinx-thebe.svg)](https://pypi.org/project/sphinx-thebe)

Integrate interactive code blocks into your documentation with Thebe and Binder.

See [the sphinx-thebe documentation](https://sphinx-thebe.readthedocs.io/en/latest/) for more details!

## Install

To install `sphinx-thebe` first clonse and install it:

```
pip install sphinx-thebe
```

Then, add it to your Sphinx site's `conf.py` file:

```
extensions = [
    ...
    "sphinx_thebe"
    ...
]
```

See [the sphinx-thebe documentation](https://sphinx-thebe.readthedocs.io/en/latest/) for more details!
